local boards = require 'boards'
local extents = require 'boards.extents'
local panelization = require 'boards.panelization'

local makeymusic = assert(boards.load('../../eagle/makeymusic/makeymusic'))
local avrpocket = assert(boards.load('../../../../git/sparkfun/Pocket_AVR_Programmer/Hardware/AVR-Pocket-Programmer'))
local micropython = assert(boards.load('../../../../git/micropython/pyboard/eagle/pyboard'))
local adafruitpowerboost1000c = assert(boards.load('../../../../git/adafruit/Adafruit-PowerBoost-1000C/Adafruit PowerBoost 1000C Rev B'))

for k, v in pairs( avrpocket.images.drill.format ) do
   print(k, v)
end
-- excellon overrides
avrpocket.images.drill.format.zeroes = 'L'
avrpocket.images.drill.format.integer = 2
avrpocket.images.drill.format.decimal = 6
micropython.images.drill.format.zeroes = 'L'
micropython.images.drill.format.integer = 2
micropython.images.drill.format.decimal = 6
adafruitpowerboost1000c.images.drill.format.zeroes = 'L'
adafruitpowerboost1000c.images.drill.format.integer = 2
adafruitpowerboost1000c.images.drill.format.decimal = 6
makeymusic.images.drill.format.zeroes = 'L'
makeymusic.images.drill.format.integer = 2
makeymusic.images.drill.format.decimal = 6

for k, v in pairs( avrpocket.images.drill.format ) do
   print(k, v)
end

-- size
max_panel_height = 10e9
max_panel_width = 10e9

-- options
local spacing = 1.7e9
local options = {}
options["spacing"] = spacing;

-- extract extents and print them
local makeymusic_extents = extents.compute_board_extents(makeymusic)
local avrpocket_extents = extents.compute_board_extents(avrpocket)
local micropython_extents = extents.compute_board_extents(micropython)
local adafruitpowerboost1000c_extents = extents.compute_board_extents(adafruitpowerboost1000c)

local makeymusic_height=makeymusic_extents["top"]-makeymusic_extents["bottom"]
local makeymusic_width=makeymusic_extents["right"]-makeymusic_extents["left"]
print("makeymusic", makeymusic_height, makeymusic_width)

local avrpocket_height=avrpocket_extents["top"]-avrpocket_extents["bottom"]
local avrpocket_width=avrpocket_extents["right"]-avrpocket_extents["left"]
print("avrpocket", avrpocket_height, avrpocket_width)

local micropython_height=micropython_extents["top"]-micropython_extents["bottom"]
local micropython_width=micropython_extents["right"]-micropython_extents["left"]
print("micropython", micropython_height, micropython_width)

local adafruitpowerboost1000c_height=adafruitpowerboost1000c_extents["top"]-adafruitpowerboost1000c_extents["bottom"]
local adafruitpowerboost1000c_width=adafruitpowerboost1000c_extents["right"]-adafruitpowerboost1000c_extents["left"]
print("adafruitpowerboost1000c", adafruitpowerboost1000c_height, adafruitpowerboost1000c_width)

-- make all the top panels the same height
local tab1 = panelization.empty_board(avrpocket_width, makeymusic_height-avrpocket_height)
local avrpocket_panel = panelization.panelize({tab1, avrpocket}, options, true)

local tab2 = panelization.empty_board(micropython_width, makeymusic_height-micropython_height)
local micropython_panel = panelization.panelize({tab2, micropython}, options, true)

local tab3 = panelization.empty_board(adafruitpowerboost1000c_width, makeymusic_height-adafruitpowerboost1000c_height)
local adafruitpowerboost1000c_panel = panelization.panelize({tab3, adafruitpowerboost1000c}, options, true)

local top_panel = assert(panelization.panelize({avrpocket_panel,  micropython_panel, adafruitpowerboost1000c_panel, tab4}, options, false))

-- extract top panel extents
local top_panel_extents = extents.compute_board_extents(top_panel)
local top_panel_height=top_panel_extents["top"]-top_panel_extents["bottom"]
local top_panel_width=top_panel_extents["right"]-top_panel_extents["left"]
print("top_panel", top_panel_height, top_panel_width)

-- pad out top panel to same width as bottom
local tab4 = panelization.empty_board(makeymusic_width-top_panel_width-spacing, top_panel_height)
local full_top_panel = assert(panelization.panelize({top_panel, tab4}, options, false))
local full_top_panel_extents = extents.compute_board_extents(full_top_panel)
local full_top_panel_height=full_top_panel_extents["top"]-full_top_panel_extents["bottom"]
local full_top_panel_width=full_top_panel_extents["right"]-full_top_panel_extents["left"]
print("full_top_panel", full_top_panel_height, full_top_panel_width)

-- final panel
local panel = assert(panelization.panelize({full_top_panel,  makeymusic}, options, true))
boards.merge_apertures(panel)

local panel_extents = extents.compute_board_extents(panel)
local panel_height=panel_extents["top"]-panel_extents["bottom"]
local panel_width=panel_extents["right"]-panel_extents["left"]
print("panel", panel_height, panel_width)

assert(boards.save(panel, './final/tkeddie_201509_2'))


